#[non_exhaustive]pub struct RustPileupConfig {
pub onlyprimary: bool,
pub minqual: u8,
pub minscore: u8,
pub reversedel: bool,
pub outputends: bool,
/* private fields */
}Expand description
Config for RustPileUp. Number of arguments might change over time and therefore is not exhaustive, please use functions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.onlyprimary: boolminqual: u8minscore: u8reversedel: booloutputends: boolImplementations
Sourceimpl RustPileupConfig
impl RustPileupConfig
Sourcepub fn new(
onlyprimary: bool,
minqual: u8,
minscore: u8,
reversedel: bool,
outputends: bool,
) -> Self
pub fn new( onlyprimary: bool, minqual: u8, minscore: u8, reversedel: bool, outputends: bool, ) -> Self
Configuration for pileup. Recalculate BAM must be off (else panics)
Sourcepub fn getBAMrecalculate(&self) -> bool
pub fn getBAMrecalculate(&self) -> bool
Get BAM recalculation, is not implemented so cannot be changed and must be false
pub fn isonlyprimary(&self) -> bool
pub fn setonlyprimary(&mut self, primary: bool)
pub fn getminqual(&self) -> u8
pub fn setminqual(&mut self, minqual: u8)
pub fn getminscore(&self) -> u8
pub fn setminscore(&mut self, minscore: u8)
pub fn hasreversedel(&self) -> bool
pub fn setreversedel(&mut self, reversedel: bool)
pub fn hasoutputends(&self) -> bool
pub fn setoutputends(&mut self, outputends: bool)